@@ -56,6 +56,10 @@ Documentation links:
            commands='\n\t'.join(commands)))
 
 
+def command_version(*argv):
+    print('Version: ' + __meta__.version)
+
+
 def command_create(working_dir: str, project_name, *argv):
     print('working-dir:' + working_dir)
     pkg_root = os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))
@@ -68,7 +72,7 @@ def command_create(working_dir: str, project_name, *argv):
         sys.exit(1)
 
     # 示例目录
-    sample_path = os.path.abspath(os.path.join(pkg_root, 'assets_for_dev', 'sample'))
+    sample_path = os.path.abspath(os.path.join(pkg_root, 'internal_assets', 'sample'))
     print('Creating structure')
     shutil.copytree(sample_path, project_path)
 
